@@ -4,14 +4,15 @@ from uuid import UUID
 
 from loguru import logger
 
-from botx.bots.mixins.requests import (  # noqa: WPS235
-    bots,
+from botx.bots.mixins.requests import bots  # noqa: WPS235
+from botx.bots.mixins.requests import (
     chats,
     command,
     events,
     files,
     internal_bot_notification,
     notification,
+    smartapps,
     stickers,
     users,
 )
@@ -48,6 +49,7 @@ class BotXRequestsMixin(  # noqa: WPS215
     users.UsersRequestsMixin,
     internal_bot_notification.InternalBotNotificationRequestsMixin,
     files.FilesRequestsMixin,
+    smartapps.SmartAppMixin,
     stickers.StickersMixin,
 ):
     """Mixin that defines methods for communicating with BotX API."""
