@@ -5,7 +5,7 @@ from uuid import UUID
 from pydantic import BaseModel
 
 from botx.clients.methods.base import APIErrorResponse, BotXMethod
-from botx.clients.methods.wrappers import HTTPResponse
+from botx.clients.types.http import HTTPResponse
 from botx.exceptions import BotXAPIError
 
 
@@ -41,7 +41,7 @@ def handle_error(method: BotXMethod, response: HTTPResponse) -> NoReturn:
     raise ChatNotFoundError(
         url=method.url,
         method=method.http_method,
-        response_content=response.bytes_body,
+        response_content=response.json_body,
         status_content=response.status_code,
         group_chat_id=error_data.group_chat_id,
     )
