@@ -1,7 +1,7 @@
 """Definition of different schemas for system events."""
 
 from types import MappingProxyType
-from typing import Any, Dict, List, Mapping, Type
+from typing import Any, Dict, List, Mapping, Optional, Type
 from uuid import UUID
 
 from botx.clients.types.message_payload import InternalBotNotificationPayload
@@ -80,6 +80,25 @@ class CTSLogoutEvent(BotXBaseModel):
     cts_id: UUID
 
 
+class SmartAppEvent(BotXBaseModel):
+    """Shape for `system:smartapp_event` event data."""
+
+    #: unique request id
+    ref: Optional[UUID] = None
+
+    #: smartapp id
+    smartapp_id: UUID
+
+    #: event data
+    data: Dict[str, Any]  # noqa: WPS110
+
+    #: event options
+    opts: Dict[str, Any] = {}
+
+    #: version of protocol smartapp <-> bot
+    smartapp_api_version: int
+
+
 # dict for validating shape for different events
 EVENTS_SHAPE_MAP: Mapping[SystemEvents, Type[BotXBaseModel]] = MappingProxyType(
     {
@@ -90,5 +109,6 @@ EVENTS_SHAPE_MAP: Mapping[SystemEvents, Type[BotXBaseModel]] = MappingProxyType(
         SystemEvents.internal_bot_notification: InternalBotNotificationEvent,
         SystemEvents.cts_login: CTSLoginEvent,
         SystemEvents.cts_logout: CTSLogoutEvent,
+        SystemEvents.smartapp_event: SmartAppEvent,
     },
 )
