@@ -9,7 +9,13 @@ from pydantic import BaseModel
 from botx.clients.methods.base import APIResponse
 from botx.clients.methods.v3.command.command_result import CommandResult
 from botx.clients.methods.v3.notification.direct_notification import NotificationDirect
-from botx.clients.types.response_results import PushResult
+from botx.clients.methods.v4.notifications.internal_bot_notification import (
+    InternalBotNotification,
+)
+from botx.clients.types.response_results import (
+    InternalBotNotificationResult,
+    PushResult,
+)
 
 
 class PydanticResponse(Response):
@@ -17,7 +23,8 @@ class PydanticResponse(Response):
 
     def __init__(
         self,
-        model: BaseModel,
+        model: Optional[BaseModel],
+        raw_data: Optional[str] = None,
         status_code: str = HTTP_200,
         headers: Optional[Dict[Any, Any]] = None,
     ) -> None:
@@ -25,15 +32,16 @@ class PydanticResponse(Response):
 
         Arguments:
             model: pydantic model that should be encoded.
+            raw_data: raw data that should be encoded.
             status_code: response HTTP status code.
             headers: headers for response.
         """
-        headers = headers or {}
-        headers["Content-Type"] = "application/json"
+        headers = headers or {"Content-Type": "application/json"}
+
         super().__init__(
             status_code,
             headers,
-            model.json(by_alias=True),
+            raw_data or model.json(by_alias=True),  # type: ignore
         )
 
 
@@ -52,3 +60,22 @@ def generate_push_response(
     return PydanticResponse(
         APIResponse[PushResult](result=PushResult(sync_id=sync_id)),
     )
+
+
+def generate_internal_bot_notification_response(
+    payload: InternalBotNotification,
+) -> Response:
+    """Generate response as like internal bot notification was sent.
+
+    Arguments:
+        payload: sent notification.
+
+    Returns:
+        Response with sync_id for new message.
+    """
+    sync_id = uuid.uuid4()
+    return PydanticResponse(
+        APIResponse[InternalBotNotificationResult](
+            result=InternalBotNotificationResult(sync_id=sync_id),
+        ),
+    )
